Statement

Struct Statement 

pub struct Statement { /* private fields */ }
A prepared statement.

Only Connection can own this type, everything else may only borrow it.

Implementations

Source

impl Statement

pub fn bind<T: Bindable>(&self, value: T) -> Result<()>

Bind values to parameters.

In case of integer indices, the first parameter has index 1.

Examples
let query = "SELECT * FROM users WHERE name = ?";
let handle = connection.prepare(query)?;
let statement = connection.borrow_statement(handle)?;
statement.bind((1, "Bob"))?;
let query = "SELECT * FROM users WHERE name = ?";
let handle = connection.prepare(query)?;
let statement = connection.borrow_statement(handle)?;
statement.bind(&[(1, "Bob")][..])?;
let query = "SELECT * FROM users WHERE name = :name";
let handle = connection.prepare(query)?;
let statement = connection.borrow_statement(handle)?;
statement.bind((":name", "Bob"))?;
let query = "SELECT * FROM users WHERE name = :name";
let handle = connection.prepare(query)?;
let statement = connection.borrow_statement(handle)?;
statement.bind(&[(":name", "Bob")][..])?;
let query = "SELECT * FROM users WHERE id = :id AND name = :name";
let handle = connection.prepare(query)?;
let statement = connection.borrow_statement(handle)?;
statement.bind::<&[(_, Value)]>(&[
    (":id", 1.into()),
    (":name", "Bob".into()),
][..])?;
pub fn bind_iter<T, U>(&self, value: T) -> Result<()>
where T: IntoIterator<Item = U>, U: Bindable,

Bind values to parameters via an iterator.

Examples
let query = "INSERT INTO users VALUES (:id, :name)";
let handle = connection.prepare(query)?;
let mut statement = connection.borrow_statement(handle)?;
statement.bind_iter::<_, (_, Value)>([
    (":name", "Bob".into()),
    (":id", 42.into()),
])?;
pub fn iter(&self) -> Cursor<'_>

Create a cursor.

pub fn next(&self) -> Result<State>

Advance to the next state.

The function should be called multiple times until State::Done is reached in order to evaluate the statement entirely.

pub fn read<T, U>(&self, index: U) -> Result<T>

Read a value from a column.

In case of integer indices, the first column has index 0.

pub fn column_count(&self) -> usize

Return the number of columns.

pub fn column_name<T: ColumnIndex>(&self, index: T) -> Result<&str>

Return the name of a column.

In case of integer indices, the first column has index 0.

pub fn column_names(&self) -> &[String]

Return column names.

pub fn column_type<T: ColumnIndex>(&self, index: T) -> Result<Type>

Return the type of a column.

The type becomes available after taking a step. In case of integer indices, the first column has index 0.

pub fn parameter_index(&self, parameter: &str) -> Result<Option<usize>>

Return the index for a named parameter if exists.

Examples
let query = "SELECT * FROM users WHERE name = :name";
let handle = connection.prepare(query)?;
let statement = connection.borrow_statement(handle)?;
assert_eq!(statement.parameter_index(":name")?.unwrap(), 1);
assert_eq!(statement.parameter_index(":asdf")?, None);
pub fn reset(&self) -> Result<()>

Reset the internal state.