pub struct StatementHandle(/* private fields */);Expand description
A handle to a prepared statement.
Users of this library can own this type, but they can only call methods on it by giving it to a Connection to borrow a full Statement.