BindableWithIndex

Trait BindableWithIndex 

pub trait BindableWithIndex {
    // Required method
    fn bind<T: ParameterIndex>(self, _: &Statement, _: T) -> Result<()>;
}
A type suitable for binding to a prepared statement given a parameter index.

Required Methods

fn bind<T: ParameterIndex>(self, _: &Statement, _: T) -> Result<()>

Bind to a parameter.

In case of integer indices, the first parameter has index 1.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl BindableWithIndex for &[u8]

Source

fn bind<T: ParameterIndex>(self, statement: &Statement, index: T) -> Result<()>

Source

impl BindableWithIndex for &str

Source

fn bind<T: ParameterIndex>(self, statement: &Statement, index: T) -> Result<()>

Source

impl BindableWithIndex for ()

Source

fn bind<T: ParameterIndex>(self, statement: &Statement, index: T) -> Result<()>

Source

impl BindableWithIndex for f64

Source

fn bind<T: ParameterIndex>(self, statement: &Statement, index: T) -> Result<()>

Source

impl BindableWithIndex for i64

Source

fn bind<T: ParameterIndex>(self, statement: &Statement, index: T) -> Result<()>

Source

impl<T> BindableWithIndex for &Option<T>

Source

fn bind<U: ParameterIndex>(self, statement: &Statement, index: U) -> Result<()>

Source

impl<T> BindableWithIndex for Option<T>

Source

fn bind<U: ParameterIndex>(self, statement: &Statement, index: U) -> Result<()>

Implementors